Processor.App.processor_utils.DomainRecord — CommonCrawl Extractor 1.0 documentation

Toggle navigation sidebar
Toggle in-page Table of Contents

# Processor.App.processor_utils.DomainRecord

class Processor.App.processor_utils.DomainRecord(filename: str, url: str, offset: int, length: int, digest: str | None = None, encoding: str | None = None, timestamp: datetime.datetime = datetime.datetime(2022, 11, 10, 21, 20, 56, 618654))
  __init__(filename: str, url: str, offset: int, length: int, digest: Optional[str] = None, encoding: Optional[str] = None, timestamp: datetime = datetime.datetime(2022, 11, 10, 21, 20, 56, 618654)) → None

  Methods

  `__init__`(filename, url, offset, length[, ...]) |

  Attributes

  `digest` |
  `encoding` |
  `timestamp` |
  `filename` |
  `url` |
  `offset` |
  `length` |